@@ -1,22 +1,88 @@
 import re
-from typing import Dict, List, Optional, Tuple
-
 from email.mime.application import MIMEApplication
+from html.parser import HTMLParser
+from io import StringIO
+from tkinter import Image
+from typing import Any, Dict, List, Optional, Tuple
 
 from PIL import ImageFont
 
-from emailify.models import Style, Table
+from emailify.models import Component, Fill, Link, Style, Table, Text
 from emailify.renderers.core import _render
+from emailify.renderers.fill import render_fill
+from emailify.renderers.image import render_image
+from emailify.renderers.link import render_link
+from emailify.renderers.render_mjml import mjml2html
 from emailify.renderers.style import merge_styles, render_style
+from emailify.renderers.text import render_text
 from emailify.styles.table_default import COL_STYLE, HEADER_STYLE
 
 DEFAULT_FONT_FAMILY = "Arial"
 DEFAULT_FONT_SIZE = 11
 
+TABLE_RENDER_MAP = {
+    Text: render_text,
+    Fill: render_fill,
+    Image: render_image,
+    Link: render_link,
+}
+
+
+EXTRACT_RE = re.compile(r"__BEG__.*?<div\b[^>]*>(.*?)<\/div>.*?__END__", re.DOTALL)
+
+
+def _render_component(
+    component: Component,
+) -> tuple[str, list[MIMEApplication]]:
+    parts: list[str] = []
+    attachments: list[MIMEApplication] = []
+
+    components = [
+        Text(text="__BEG__"),
+        component,
+        Text(text="__END__"),
+    ]
+    for component in components:
+        body, cur_attachments = TABLE_RENDER_MAP[type(component)](component)
+        parts.append(body)
+        attachments.extend(cur_attachments)
+
+    body_str = _render(
+        "index",
+        content="".join(parts),
+    )
+    html = mjml2html(body_str)
+
+    match = EXTRACT_RE.search(html)
+    if match:
+        html = match.group(1).strip()
+
+    return html, attachments
+
+
+class MLStripper(HTMLParser):
+    def __init__(self):
+        super().__init__()
+        self.reset()
+        self.text = StringIO()
+
+    def handle_data(self, d):
+        self.text.write(d)
+
+    def get_data(self):
+        return self.text.getvalue()
+
+
+def strip_tags(html: str) -> str:
+    s = MLStripper()
+    s.feed(html)
+    return s.get_data()
+
 
 def _get_text_size(
     text: str, font_size: Optional[int], font_family: Optional[str]
 ) -> float:
+    text = strip_tags(text)
     size = font_size or DEFAULT_FONT_SIZE
     family = (font_family or DEFAULT_FONT_FAMILY).lower()
     try:
@@ -58,7 +124,22 @@ def render_style_dict(style_dict: Dict[str, Style]) -> Dict[str, str]:
     }
 
 
+EXTRA_ATTACHMENTS: list[MIMEApplication] = []
+
+
+def maybe_render_nested(cell: Any) -> Any:
+    if not isinstance(cell, Component):
+        return cell
+    body, attachments = _render_component(cell)
+    EXTRA_ATTACHMENTS.extend(attachments)
+    return body
+
+
 def render_table(table: Table) -> tuple[str, list[MIMEApplication]]:
+    global EXTRA_ATTACHMENTS
+    EXTRA_ATTACHMENTS = []
+
+    table.data = table.data.map(maybe_render_nested)
     row_styles: Dict[int, str] = {}
     header_styles: Dict[str, str] = {}
     col_styles: Dict[str, str] = {}
@@ -172,4 +253,4 @@ def render_table(table: Table) -> tuple[str, list[MIMEApplication]]:
         headers_render=headers_render,
         body_nowrap_cols=body_nowrap_cols,
     )
-    return body, []
+    return body, EXTRA_ATTACHMENTS
