@@ -23,7 +23,11 @@ def test_api():
     df = pd.DataFrame(
         {
             "hello2": [1, 2, 3],
-            "hello": ["My", "Name", "Is"],
+            "hello": [
+                "My",
+                ef.Link(text="Google", href="https://www.google.com"),
+                "Is",
+            ],
             "hello3": ["My", "Name", "Is"],
             "Really long column name": [1, 2, 3],
             "hello4": ["This is a long column name"] * 3,
@@ -36,6 +40,7 @@ def test_api():
             text="Hello, this is a table with merged headers",
             style=ef.Style(background_color="#cbf4c9", padding_left="5"),
         ),
+        ef.Link(text="Hello", href="https://www.google.com"),
         ef.Table(
             data=df,
             merge_equal_headers=True,
